FallbackErrorHandler

Struct FallbackErrorHandler 

pub struct FallbackErrorHandler(pub ErrorHandler);
Fallback error handler to call when an error is not handled otherwise. Defaults to match_severity().

When updated while a Schedule is running, it doesn’t take effect for that schedule until it’s completed.

Tuple Fields

0: ErrorHandler